@@ -1,5 +1,5 @@
 
-# $Id: Ethernet.pm,v 1.116 2013-01-21 16:10:10 Martin Exp $
+# $Id: Ethernet.pm,v 1.117 2013/03/26 22:57:38 martin Exp $
 
 =head1 NAME
 
@@ -37,7 +37,7 @@ use constant DEBUG_MATCH => 0;
 
 use vars qw( $DEBUG $VERSION @EXPORT_OK %EXPORT_TAGS );
 use base 'Exporter';
-$VERSION = do { my @r = (q$Revision: 1.116 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.117 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 $DEBUG = 0 || $ENV{N_A_E_DEBUG};
 
@@ -116,6 +116,10 @@ sub get_addresses
   goto ALL_DONE if @ahInfo;
   my $sAddr = undef;
   my $rh = Ifconfig('list', '', '', '');
+  if (! defined $rh || (! scalar keys %$rh))
+    {
+    warn " EEE ifconfig failed: $@";
+    } # if
   _debug(" DDD raw output from Ifconfig is ", Dumper($rh));
   # Convert their hashref to our array format:
   foreach my $key (keys %$rh)
